@@ -1,4 +1,3 @@
-
 #' Function to find the mode
 #' @param x vector with numbers
 #' @return  Mode value
@@ -47,7 +46,11 @@ fit_model_rmse <- function(object,
     Nvariable_totals <- length(data_train)
     variable_names <- colnames(data_train[(first_n_predictors + 1):(Nvariable_totals - 2)])
   } else {
-    variable_names <- "id_nr"
+    if ("strata" %in% colnames(data_train)) {
+      variable_names <- c("id_nr", "strata")
+    } else {
+      variable_names <- c("id_nr")
+    }
   }
 
   # Get number of embeddings provided
@@ -65,10 +68,9 @@ fit_model_rmse <- function(object,
     if (!impute_missing) {
       xy_recipe <- recipes::step_naomit(xy_recipe, recipes::all_predictors(), skip = TRUE)
     } else if (impute_missing) {
-      xy_recipe <- recipes::step_impute_knn(xy_recipe, recipes::all_predictors(), neighbors = 10) # , skip = TRUE
+      xy_recipe <- recipes::step_impute_knn(xy_recipe, recipes::all_predictors(), neighbors = 10)
     }
 
-
     if (preprocess_step_center) {
       xy_recipe <- recipes::step_center(xy_recipe, recipes::all_predictors())
     }
@@ -100,13 +102,19 @@ fit_model_rmse <- function(object,
       recipes::recipe(y ~ .) %>%
       # recipes::step_BoxCox(all_predictors()) %>%  preprocess_PCA = NULL, preprocess_PCA = 0.9 preprocess_PCA = 2
       recipes::update_role(id_nr, new_role = "id variable") %>%
-      recipes::update_role(-id_nr, new_role = "predictor") %>%
+      #  recipes::update_role(-id_nr, new_role = "predictor") %>%
       recipes::update_role(y, new_role = "outcome")
 
+
+    if ("strata" %in% colnames(data_train)) {
+      xy_recipe <- xy_recipe %>%
+        recipes::update_role(strata, new_role = "strata")
+    }
+
     if (!impute_missing) {
       xy_recipe <- recipes::step_naomit(xy_recipe, recipes::all_predictors(), skip = TRUE)
     } else if (impute_missing) {
-      xy_recipe <- recipes::step_impute_knn(xy_recipe, recipes::all_predictors(), neighbors = 10) # , skip = TRUE
+      xy_recipe <- recipes::step_impute_knn(xy_recipe, recipes::all_predictors(), neighbors = 10)
     }
 
     if (preprocess_step_center) {
@@ -141,7 +149,7 @@ fit_model_rmse <- function(object,
 
   # Figure out how many predictors to know whether to use simple or multiple regression, which
   # depend on number of of PCA components that are retrived and/or whether first_n_predictors is used
-  if (!is.na(first_n_predictors) & is.na(preprocess_PCA)) {
+  if (!is.na(first_n_predictors) && is.na(preprocess_PCA)) {
     # Get number of predictors from receipe
     nr_predictors <- table(xy_recipe_prep[[1]]$role)[["predictor"]]
   } else if (!is.na(preprocess_PCA)) {
@@ -150,7 +158,7 @@ fit_model_rmse <- function(object,
     nr_predictors <- recipes::juice(xy_recipe_prep)
     # Count number of PCAs
     nr_predictors <- length(grep(x = colnames(nr_predictors), pattern = "PC"))
-  } else if (is.na(preprocess_PCA) & is.na(first_n_predictors)) {
+  } else if (is.na(preprocess_PCA) && is.na(first_n_predictors)) {
     nr_predictors <- recipes::juice(xy_recipe_prep)
     nr_predictors <- length(nr_predictors) - 2
   }
@@ -168,7 +176,7 @@ fit_model_rmse <- function(object,
             penalty = penalty,
             mixture = mixture
           )
-        } else if (model =="multinomial") {
+        } else if (model == "multinomial") {
           parsnip::multinom_reg(
             mode = "classification",
             penalty = penalty,
@@ -219,12 +227,12 @@ fit_model_rmse <- function(object,
     holdout_pred <-
       stats::predict(mod, xy_testing) %>%
       dplyr::bind_cols(rsample::assessment(object) %>%
-        dplyr::select(y, id_nr))
+                         dplyr::select(y, id_nr))
 
     # Get RMSE; eval_measure = "rmse" library(tidyverse)
     eval_result <- select_eval_measure_val(eval_measure,
-                                           holdout_pred = holdout_pred,
-                                           truth = y, estimate = .pred
+      holdout_pred = holdout_pred,
+      truth = y, estimate = .pred
     )$.estimate
     # Sort output of RMSE, predictions and truth (observed y)
     output <- list(
@@ -248,8 +256,8 @@ fit_model_rmse <- function(object,
 
     # Get RMSE; eval_measure = "rmse"
     eval_result <- select_eval_measure_val(eval_measure,
-                                           holdout_pred = holdout_pred,
-                                           truth = y, estimate = .pred_class
+      holdout_pred = holdout_pred,
+      truth = y, estimate = .pred_class
     )$.estimate
     # Sort output of RMSE, predictions and truth (observed y)
     output <- list(
@@ -286,27 +294,27 @@ fit_model_rmse <- function(object,
 
     # Get RMSE; eval_measure = "rmse"
     eval_result <- select_eval_measure_val(eval_measure,
-                                           holdout_pred = holdout_pred,
-                                           truth = y, estimate = .pred_class
+      holdout_pred = holdout_pred,
+      truth = y, estimate = .pred_class
     )$.estimate
     # Sort output of RMSE, predictions and truth (observed y)
     output <- list(
       list(eval_result),
       list(holdout_pred$.pred_class),
       list(holdout_pred$y)
-      )
-      for (i in 1:length(unique(levels(holdout_pred$y))))
-      {
-        output[[3+i]]<-list(holdout_pred[i])
-      }
-      output[[length(output)+1]]<-list(preprocess_PCA)
-      output[[length(output)+1]]<-list(holdout_pred$id_nr)
+    )
+    for (i in 1:length(unique(levels(holdout_pred$y))))
+    {
+      output[[3 + i]] <- list(holdout_pred[i])
+    }
+    output[[length(output) + 1]] <- list(preprocess_PCA)
+    output[[length(output) + 1]] <- list(holdout_pred$id_nr)
 
-      pred_names<-list()
-      for (i in 1:length(unique(levels(holdout_pred$y))))
-      {
-        pred_names[i]<-paste(".pred_", i, sep = "")
-      }
+    pred_names <- list()
+    for (i in 1:length(unique(levels(holdout_pred$y))))
+    {
+      pred_names[i] <- paste(".pred_", i, sep = "")
+    }
     names(output) <- c(
       "eval_result",
       "estimate",
@@ -345,16 +353,16 @@ fit_model_rmse_wrapper <- function(penalty = penalty,
                                    preprocess_step_scale = preprocess_step_scale,
                                    impute_missing = impute_missing) {
   fit_model_rmse(object,
-                 model,
-                 eval_measure,
-                 penalty,
-                 mixture,
-                 preprocess_PCA = preprocess_PCA,
-                 variable_name_index_pca = variable_name_index_pca,
-                 first_n_predictors = first_n_predictors,
-                 preprocess_step_center = preprocess_step_center,
-                 preprocess_step_scale = preprocess_step_scale,
-                 impute_missing = impute_missing
+    model,
+    eval_measure,
+    penalty,
+    mixture,
+    preprocess_PCA = preprocess_PCA,
+    variable_name_index_pca = variable_name_index_pca,
+    first_n_predictors = first_n_predictors,
+    preprocess_step_center = preprocess_step_center,
+    preprocess_step_scale = preprocess_step_scale,
+    impute_missing = impute_missing
   )
 }
 
@@ -430,20 +438,21 @@ tune_over_cost <- function(object,
   )
 
   #  Test models with the different hyperparameters for the inner samples
-  tune_results <- purrr::pmap(list(
-    grid_inner$penalty,
-    grid_inner$mixture,
-    grid_inner$preprocess_PCA,
-    grid_inner$first_n_predictors
-  ),
-  fit_model_rmse_wrapper,
-  object = object,
-  model = model,
-  eval_measure = eval_measure,
-  variable_name_index_pca = variable_name_index_pca,
-  preprocess_step_center = preprocess_step_center,
-  preprocess_step_scale = preprocess_step_scale,
-  impute_missing = impute_missing
+  tune_results <- purrr::pmap(
+    list(
+      grid_inner$penalty,
+      grid_inner$mixture,
+      grid_inner$preprocess_PCA,
+      grid_inner$first_n_predictors
+    ),
+    fit_model_rmse_wrapper,
+    object = object,
+    model = model,
+    eval_measure = eval_measure,
+    variable_name_index_pca = variable_name_index_pca,
+    preprocess_step_center = preprocess_step_center,
+    preprocess_step_scale = preprocess_step_scale,
+    impute_missing = impute_missing
   )
 
   # Sort the output to separate the rmse, predictions and truth
@@ -530,7 +539,6 @@ summarize_tune_results <- function(object,
                                    preprocess_step_center = preprocess_step_center,
                                    preprocess_step_scale = preprocess_step_scale,
                                    impute_missing = impute_missing) {
-
   # Return row-bound tibble containing the INNER results
   results <- purrr::map_df(
     .x = object$splits,
@@ -552,76 +560,91 @@ summarize_tune_results <- function(object,
 
 
 #' Train word embeddings to a numeric variable.
-#'
 #' @param x Word embeddings from textEmbed (or textEmbedLayerAggregation). If several word embedding are
 #' provided in a list they will be concatenated.
-#' @param x_append Variables to be appended after the word embeddings (x); if wanting to preappend them before
-#' the word embeddings use the option first = TRUE. If not wanting to train with word embeddings, set x = NULL.
-#' @param append_first (boolean) Option to add variables before or after all word embeddings.
 #' @param y Numeric variable to predict.
-#' @param model Type of model. Default is "regression"; see also "logistic" and "multinomial" for classification.
-#' @param cv_method Cross-validation method to use within a pipeline of nested outer and inner loops
+#' @param x_append (optional) Variables to be appended after the word embeddings (x);
+#' if wanting to preappend them before the word embeddings use the option first = TRUE.
+#' If not wanting to train with word embeddings, set x = NULL (default = NULL).
+#' @param append_first (boolean) Option to add variables before or after all word embeddings (default = False).
+#' @param cv_method (character) Cross-validation method to use within a pipeline of nested outer and inner loops
 #' of folds (see nested_cv in rsample). Default is using cv_folds in the outside folds and "validation_split"
 #' using rsample::validation_split in the inner loop to achieve a development and assessment set (note that
 #' for validation_split the inside_folds should be a proportion, e.g., inside_folds = 3/4); whereas "cv_folds"
 #' uses rsample::vfold_cv to achieve n-folds in both the outer and inner loops.
-#' @param outside_folds Number of folds for the outer folds (default = 10).
-#' @param outside_strata_y Variable to stratify according (default y; can set to NULL).
-#' @param outside_breaks The number of bins wanted to stratify a numeric stratification variable in the
-#' outer cross-validation loop.
-#' @param inside_folds The proportion of data to be used for modeling/analysis; (default proportion = 3/4).
+#' @param outside_folds (numeric) Number of folds for the outer folds (default = 10).
+#' @param inside_folds (numeric) The proportion of data to be used for modeling/analysis; (default proportion = 3/4).
 #' For more information see validation_split in rsample.
-#' @param inside_strata_y Variable to stratify according (default y; can set to NULL).
+#' @param strata (string or tibble; default "y") Variable to stratify according;
+#' if a string the variable needs to be in the training set - if you want to stratify
+#' according to another variable you can include it as a tibble (please note you
+#' can only add 1 variable to stratify according). Can set it to NULL.
+#' @param outside_strata (boolean) Whether to stratify the outside folds.
+#' @param outside_breaks (numeric) The number of bins wanted to stratify a numeric stratification variable in the
+#' outer cross-validation loop (default = 4).
+#' @param inside_strata Whether to stratify the outside folds.
 #' @param inside_breaks The number of bins wanted to stratify a numeric stratification variable in the inner
-#' cross-validation loop.
-#' @param eval_measure Type of evaluative measure to select models from. Default = "rmse" for regression and
+#' cross-validation loop (default = 4).
+#' @param model Type of model. Default is "regression"; see also "logistic" and "multinomial" for classification.
+#' @param eval_measure (character) Type of evaluative measure to select models from. Default = "rmse" for regression and
 #' "bal_accuracy" for logistic. For regression use "rsq" or "rmse"; and for classification use "accuracy",
 #'  "bal_accuracy", "sens", "spec", "precision", "kappa", "f_measure", or "roc_auc",(for more details see
 #'  the yardstick package).
-#' @param preprocess_step_center normalizes dimensions to have a mean of zero; default is set to TRUE.
+#' @param preprocess_step_center (boolean) Normalizes dimensions to have a mean of zero; default is set to TRUE.
 #' For more info see (step_center in recipes).
-#' @param preprocess_step_scale  normalize dimensions to have a standard deviation of one.
-#' For more info see (step_scale in recipes).
+#' @param preprocess_step_scale (boolean) Normalize dimensions to have a standard deviation of one;
+#'  default is set to TRUE. For more info see (step_scale in recipes).
 #' @param preprocess_PCA Pre-processing threshold for PCA (to skip this step set it to NA).
 #' Can select amount of variance to retain (e.g., .90 or as a grid c(0.80, 0.90)); or
 #' number of components to select (e.g., 10). Default is "min_halving", which is a function
 #' that selects the number of PCA components based on number  of participants and feature (word embedding dimensions)
 #' in the data. The formula is:
 #' preprocess_PCA = round(max(min(number_features/2), number_participants/2), min(50, number_features))).
-#' @param penalty hyper parameter that is tuned
+#' @param penalty (numeric) Hyper parameter that is tuned (default = 10^seq(-16,16)).
 #' @param mixture A number between 0 and 1 (inclusive) that reflects the proportion of L1 regularization
 #' (i.e. lasso) in the model (for more information see the linear_reg-function in the parsnip-package).
 #' When mixture = 1, it is a pure lasso model while mixture = 0 indicates that ridge regression is being
 #' used (specific engines only).
-#' @param first_n_predictors by default this setting is turned off (i.e., NA). To use this method,
+#' @param first_n_predictors By default this setting is turned off (i.e., NA). To use this method,
 #' set it to the highest number of predictors you want to test. Then the X first dimensions are used in training,
 #' using a sequence from Kjell et al., 2019 paper in Psychological Methods. Adding 1,
 #' then multiplying by 1.3 and finally rounding to the nearest integer (e.g., 1, 3, 5, 8).
 #' This option is currently only possible for one embedding at the time.
 #' @param method_cor Type of correlation used in evaluation (default "pearson";
 #' can set to "spearman" or "kendall").
-#' @param impute_missing default FALSE (can be set to TRUE if something else than word_embeddings are trained).
-#' @param model_description Text to describe your model (optional; good when sharing the model with others).
+#' @param impute_missing Default FALSE (can be set to TRUE if something else than word_embeddings are trained).
+#' @param model_description (character) Text to describe your model (optional; good when sharing the model with others).
 #' @param multi_cores If TRUE it enables the use of multiple cores if the computer system allows for it
 #'  (i.e., only on unix, not windows). Hence it makes the analyses considerably faster to run. Default is
 #'  "multi_cores_sys_default", where it automatically uses TRUE for Mac and Linux and FALSE for Windows.
-#' @param save_output Option not to save all output; default "all". see also "only_results"
+#' @param save_output (character) Option not to save all output; default = "all". see also "only_results"
 #'  and "only_results_predictions".
-#' @param seed Set different seed.
+#' @param simulate.p.value (Boolean) From fisher.test: a logical indicating whether to compute p-values by
+#' Monte Carlo simulation, in larger than 2 × 2 tables.
+#' @param seed (numeric) Set different seed (default = 2020).
 #' @param ... For example settings in yardstick::accuracy to set event_level (e.g., event_level = "second").
 #' @return A (one-sided) correlation test between predicted and observed values; tibble
-#' of predicted values, as well as information about the model (preprossing_recipe, final_model
-#'  and model_description).
+#' of predicted values (t-value, degree of freedom (df), p-value,
+#'  alternative-hypothesis, confidence interval, correlation coefficient), as well as information about
+#'  the model (preprossing_recipe, final_model and model_description).
 #' @examples
-#' \donttest{
-#' results <- textTrainRegression(
+#' # Examines how well the embeddings from the column "harmonytext" can
+#' # predict the numerical values in the column "hilstotal".
+#'
+#' \dontrun{
+#' trained_model <- textTrainRegression(
 #'   x = word_embeddings_4$texts$harmonytext,
 #'   y = Language_based_assessment_data_8$hilstotal,
 #'   multi_cores = FALSE # This is FALSE due to CRAN testing and Windows machines.
 #' )
+#'
+#' # Examine results (t-value, degree of freedom (df), p-value, alternative-hypothesis,
+#' # confidence interval, correlation coefficient).
+#'
+#' trained_model$results
 #' }
-#' @seealso see \code{\link{textEmbedLayerAggregation}} \code{\link{textTrainLists}}
-#' \code{\link{textTrainRandomForest}}
+#' @seealso See \code{\link{textEmbedLayerAggregation}}, \code{\link{textTrainLists}} and
+#' \code{\link{textTrainRandomForest}}.
 #' @importFrom stats cor.test na.omit lm
 #' @importFrom dplyr bind_cols select starts_with filter all_of
 #' @importFrom recipes recipe step_naomit step_center step_scale step_pca all_predictors
@@ -639,10 +662,11 @@ textTrainRegression <- function(x,
                                 append_first = FALSE,
                                 cv_method = "validation_split",
                                 outside_folds = 10,
-                                outside_strata_y = "y",
-                                outside_breaks = 4,
                                 inside_folds = 3 / 4,
-                                inside_strata_y = "y",
+                                strata = "y",
+                                outside_strata = TRUE,
+                                outside_breaks = 4,
+                                inside_strata = TRUE,
                                 inside_breaks = 4,
                                 model = "regression",
                                 eval_measure = "default",
@@ -657,6 +681,7 @@ textTrainRegression <- function(x,
                                 model_description = "Consider writing a description of your model here",
                                 multi_cores = "multi_cores_sys_default",
                                 save_output = "all",
+                                simulate.p.value = FALSE,
                                 seed = 2020,
                                 ...) {
   T1_textTrainRegression <- Sys.time()
@@ -664,9 +689,9 @@ textTrainRegression <- function(x,
 
 
   # Select correct eval_measure depending on model when default
-  if (model == "regression" & eval_measure == "default") {
+  if (model == "regression" && eval_measure == "default") {
     eval_measure <- "rmse"
-  } else if (model == "logistic" | model == "multinomial" & eval_measure == "default") {
+  } else if (model == "logistic" || model == "multinomial" && eval_measure == "default") {
     eval_measure <- "bal_accuracy"
   }
 
@@ -679,7 +704,7 @@ textTrainRegression <- function(x,
   }
 
   # Sorting out y
-  if (tibble::is_tibble(y) | is.data.frame(y)) {
+  if (tibble::is_tibble(y) || is.data.frame(y)) {
     y_name <- colnames(y)
 
     y <- tibble::as_tibble_col(y[[1]], column_name = "y")
@@ -688,15 +713,16 @@ textTrainRegression <- function(x,
     y <- tibble::as_tibble_col(y, column_name = "y")
   }
 
-  if(model == "logistic" & anyNA(y[1])){
+  if (model == "logistic" && anyNA(y[1])) {
     stop("In logistic regression you cannot currently have any NA(s) in y.")
   }
 
   # Sorting out x's
-  variables_and_names <- sorting_xs_and_x_append(x = x,
-                                                 x_append = x_append,
-                                                 append_first = append_first,
-                                                 ...
+  variables_and_names <- sorting_xs_and_x_append(
+    x = x,
+    x_append = x_append,
+    append_first = append_first,
+    ...
   )
   x2 <- variables_and_names$x1
   x_name <- variables_and_names$x_name
@@ -707,46 +733,76 @@ textTrainRegression <- function(x,
 
   xy <- dplyr::bind_cols(x2, y)
 
-  # xy <- tibble::as_tibble(xy) xy[1537]
   xy$id_nr <- c(seq_len(nrow(xy)))
 
+  # Adding strata variable to the data set -- and then calling it "outside_strata"
+  # Which is then called in strata variable, and also made into not a predictor downstream
+  outside_strata_y <- NULL
+  inside_strata_y <- NULL
+  strata_name <- NULL
+  if (!is.null(strata)) {
+    if (tibble::is_tibble(strata)) {
+      strata_name <- colnames(strata)
+      colnames(strata) <- "strata"
+      xy <- dplyr::bind_cols(xy, strata)
+
+      if (inside_strata) {
+        outside_strata_y <- "strata"
+      }
+      if (outside_strata) {
+        inside_strata_y <- "strata"
+      }
+    }
+
+    if (strata[[1]][[1]] == "y") {
+      strata_name <- "y"
+      if (inside_strata) {
+        outside_strata_y <- "y"
+      }
+      if (outside_strata) {
+        inside_strata_y <- "y"
+      }
+    }
+  }
+
   # complete.cases is not neccassary
   # Cross-Validation inside_folds = 3/4; results_nested_resampling[[1]][[1]][[1]]
   if (cv_method == "cv_folds") {
-    results_nested_resampling <- rlang::expr(rsample::nested_cv(xy,
-                                                                outside = rsample::vfold_cv(
-                                                                  v = !!outside_folds,
-                                                                  repeats = 1,
-                                                                  strata = !!outside_strata_y,
-                                                                  breaks = !!outside_breaks
-                                                                ), #
-                                                                inside = rsample::vfold_cv(
-                                                                  v = !!inside_folds,
-                                                                  repeats = 1,
-                                                                  strata = !!inside_strata_y,
-                                                                  breaks = !!inside_breaks
-                                                                )
+    results_nested_resampling <- rlang::expr(rsample::nested_cv(
+      xy,
+      outside = rsample::vfold_cv(
+        v = !!outside_folds,
+        repeats = 1,
+        strata = !!outside_strata_y,
+        breaks = !!outside_breaks
+      ), #
+      inside = rsample::vfold_cv(
+        v = !!inside_folds,
+        repeats = 1,
+        strata = !!inside_strata_y,
+        breaks = !!inside_breaks
+      )
     ))
   }
   if (cv_method == "validation_split") {
-    results_nested_resampling <- rlang::expr(rsample::nested_cv(xy,
-                                                                outside = rsample::vfold_cv(
-                                                                  v = !!outside_folds,
-                                                                  repeats = 1,
-                                                                  strata = !!outside_strata_y,
-                                                                  breaks = !!outside_breaks
-                                                                ),
-                                                                inside = rsample::validation_split(
-                                                                  prop = !!inside_folds,
-                                                                  strata = !!inside_strata_y,
-                                                                  breaks = !!inside_breaks
-                                                                )
+    results_nested_resampling <- rlang::expr(rsample::nested_cv(
+      xy,
+      outside = rsample::vfold_cv(
+        v = !!outside_folds,
+        repeats = 1,
+        strata = !!outside_strata_y,
+        breaks = !!outside_breaks
+      ),
+      inside = rsample::validation_split(
+        prop = !!inside_folds,
+        strata = !!inside_strata_y,
+        breaks = !!inside_breaks
+      )
     ))
   }
 
   results_nested_resampling <- rlang::eval_tidy(results_nested_resampling)
 
-
   # Deciding whether to use multicores depending on system and settings.
   if (multi_cores == "multi_cores_sys_default") {
     if (.Platform$OS.type == "unix") {
@@ -851,15 +907,17 @@ textTrainRegression <- function(x,
 
     collected_results <- list(predy_y, collected_results)
   } else if (model == "logistic") {
-    collected_results <- classification_results(outputlist_results_outer = outputlist_results_outer, ...
-    )
+    collected_results <- classification_results(outputlist_results_outer = outputlist_results_outer, ...)
 
     #  Save predictions outside list to make similar structure as model == regression output.
     predy_y <- collected_results$predy_y
     # Remove the predictions from list
     collected_results[[1]] <- NULL
   } else if (model == "multinomial") {
-    collected_results <- classification_results_multi(outputlist_results_outer = outputlist_results_outer, ...
+    collected_results <- classification_results_multi(
+      outputlist_results_outer = outputlist_results_outer,
+      simulate.p.value = simulate.p.value,
+      ...
     )
 
     #  Save predictions outside list to make similar structure as model == regression output.
@@ -871,19 +929,25 @@ textTrainRegression <- function(x,
 
   ##### Construct final model to be saved and applied on other data  ########
   ############################################################################
-  xy_all <- xy
 
+  if ("strata" %in% colnames(xy)) {
+    xy_all <- xy %>%
+      dplyr::select(-strata)
+  } else {
+    xy_all <- xy
+  }
+
+  colnames(xy_all)
   ######### One word embedding as input
   n_embbeddings <- as.numeric(comment(eval_measure))
   if (n_embbeddings == 1) {
-
     # If testing N first predictors help(step_scale) first_n_predictors = 3
     if (!is.na(first_n_predictors)) {
       # Select y and id
       Nvariable_totals <- length(xy_all)
       variable_names <- colnames(xy_all[(first_n_predictors + 1):(Nvariable_totals - 2)])
     } else {
-      variable_names <- "id_nr"
+      variable_names <- c("id_nr")
     }
 
     # [0,] is added to just get the col names (and avoid saving all the data with the receipt) help(step_naomit)
@@ -891,7 +955,6 @@ textTrainRegression <- function(x,
       recipes::recipe(y ~ ., xy_all[0, ]) %>%
       recipes::update_role(all_of(variable_names), new_role = "Not_predictors") %>%
       recipes::update_role(id_nr, new_role = "id variable") %>%
-      # recipes::update_role(-id_nr, new_role = "predictor") %>%
       recipes::update_role(y, new_role = "outcome")
 
     if (!impute_missing) {
@@ -912,11 +975,11 @@ textTrainRegression <- function(x,
         if (!is.na(preprocess_PCA[1])) {
           if (preprocess_PCA[1] >= 1) {
             recipes::step_pca(., recipes::all_predictors(),
-                              num_comp = statisticalMode(results_split_parameter$preprocess_PCA)
+              num_comp = statisticalMode(results_split_parameter$preprocess_PCA)
             )
           } else if (preprocess_PCA[1] < 1) {
             recipes::step_pca(., recipes::all_predictors(),
-                              threshold = statisticalMode(results_split_parameter$preprocess_PCA)
+              threshold = statisticalMode(results_split_parameter$preprocess_PCA)
             )
           } else {
             .
@@ -978,10 +1041,16 @@ textTrainRegression <- function(x,
     env_final_recipe$xy_all <- xy_all
     env_final_recipe$final_recipe <- final_recipe
 
-    with(env_final_recipe, preprocessing_recipe_save <- suppressWarnings(recipes::prep(final_recipe,
-                                                                                       xy_all,
-                                                                                       retain = FALSE
-    )))
+    preprocessing_recipe_save <- with(
+      env_final_recipe,
+      suppressWarnings(recipes::prep(final_recipe, xy_all, retain = FALSE))
+    )
+
+    # Optionally remove xy_all if you are concerned about memory and it's no longer needed
+    remove("xy_all", envir = env_final_recipe)
+    remove("final_recipe", envir = env_final_recipe)
+
+    return(preprocessing_recipe_save)
   }
 
   preprocessing_recipe_save <- recipe_save_small_size(
@@ -996,42 +1065,37 @@ textTrainRegression <- function(x,
 
   nr_predictors <- recipes::juice(preprocessing_recipe_prep)
 
+  # This is so that nr_predictors > 3 and nr_predictors == 3 should work
+  if ("strata" %in% colnames(nr_predictors)) {
+    nr_predictors <- nr_predictors %>%
+      select(-strata)
+  }
   nr_predictors <- length(nr_predictors)
 
   ####### NEW ENVIRONMENT
-  model_save_small_size <- function(xy_all, final_recipe, results_split_parameter, model, nr_predictors) {
+  model_save_small_size <- function(xy_all, final_recipe, penalty, mixture, model, nr_predictors) {
     env_final_model <- new.env(parent = globalenv())
     env_final_model$xy_all <- xy_all
     env_final_model$final_recipe <- final_recipe
-    env_final_model$penalty_mode <- statisticalMode(results_split_parameter$penalty)
-    env_final_model$mixture_mode <- statisticalMode(results_split_parameter$mixture)
+    env_final_model$penalty_mode <- statisticalMode(penalty)
+    env_final_model$mixture_mode <- statisticalMode(mixture)
     env_final_model$model <- model
     env_final_model$nr_predictors <- nr_predictors
     env_final_model$statisticalMode <- statisticalMode
     env_final_model$`%>%` <- `%>%`
 
-    with(
-      env_final_model,
+    final_predictive_model <- with(env_final_model, {
       if (nr_predictors > 3) {
-        # Create and fit model; penalty=NULL mixture = NULL
         final_predictive_model_spec <-
-          {
-            if (model == "regression") {
-              parsnip::linear_reg(penalty = penalty_mode, mixture = mixture_mode)
-            } else if (model == "logistic") {
-              parsnip::logistic_reg(
-                mode = "classification",
-                penalty = penalty_mode,
-                mixture = mixture_mode
-              )
-            } else if (model == "multinomial") {
-              parsnip::multinom_reg(
-                mode = "classification",
-                penalty = penalty_mode,
-                mixture = mixture_mode
-              )
-            }
-          } %>%
+          if (model == "regression") {
+            parsnip::linear_reg(penalty = penalty_mode, mixture = mixture_mode)
+          } else if (model == "logistic") {
+            parsnip::logistic_reg(mode = "classification", penalty = penalty_mode, mixture = mixture_mode)
+          } else if (model == "multinomial") {
+            parsnip::multinom_reg(mode = "classification", penalty = penalty_mode, mixture = mixture_mode)
+          }
+
+        final_predictive_model_spec <- final_predictive_model_spec %>%
           parsnip::set_engine("glmnet")
 
         # Create Workflow (to know variable roles from recipes) help(workflow)
@@ -1039,12 +1103,9 @@ textTrainRegression <- function(x,
           workflows::add_model(final_predictive_model_spec) %>%
           workflows::add_recipe(final_recipe)
 
-        # Fit model
-        final_predictive_model <- parsnip::fit(wf_final, data = xy_all)
-
-        # Standard regression
+        parsnip::fit(wf_final, data = xy_all)
       } else if (nr_predictors == 3) {
-        final_predictive_model_spec <- {
+        final_predictive_model_spec <-
           if (model == "regression") {
             parsnip::linear_reg(mode = "regression") %>%
               parsnip::set_engine("lm")
@@ -1055,21 +1116,23 @@ textTrainRegression <- function(x,
             parsnip::multinom_reg(mode = "classification") %>%
               parsnip::set_engine("glmnet")
           }
-        }
 
-
-        # Create Workflow (to know variable roles from recipes) help(workflow)
         wf_final <- workflows::workflow() %>%
           workflows::add_model(final_predictive_model_spec) %>%
           workflows::add_recipe(final_recipe)
 
-        # Fit model
-        final_predictive_model <- parsnip::fit(wf_final, data = xy_all)
+        parsnip::fit(wf_final, data = xy_all)
       }
-    )
+    })
+    remove("final_recipe", envir = env_final_model)
+    remove("xy_all", envir = env_final_model)
+    return(final_predictive_model)
   }
 
-  final_predictive_model <- model_save_small_size(xy_all, final_recipe, results_split_parameter, model, nr_predictors)
+  final_predictive_model <- model_save_small_size(
+    xy_all, preprocessing_recipe_save, results_split_parameter$penalty,
+    results_split_parameter$mixture, model, nr_predictors
+  )
 
 
   ##### NEW ENVIRONMENT END
@@ -1081,10 +1144,11 @@ textTrainRegression <- function(x,
   x_append_names_description <- paste("x_append = ", x_append_names)
   y_name_description <- paste("y = ", y_name)
   cv_method_description <- paste("cv_method = ", deparse(cv_method))
+  strata_description <- paste("strata = ", strata_name)
   outside_folds_description <- paste("outside_folds = ", deparse(outside_folds))
-  outside_strata_y_description <- paste("outside_strata_y = ", deparse(outside_strata_y))
+  outside_strata_y_description <- paste("outside_strata = ", deparse(outside_strata))
   inside_folds_description <- paste("inside_folds = ", deparse(inside_folds))
-  inside_strata_y_description <- paste("inside_strata_y = ", deparse(inside_strata_y))
+  inside_strata_y_description <- paste("inside_strata = ", deparse(inside_strata))
 
   penalty_setting <- paste("penalty_setting = ", deparse(penalty))
   mixture_setting <- paste("mixture_setting = ", deparse(mixture))
@@ -1131,9 +1195,9 @@ textTrainRegression <- function(x,
   )
   Date_textTrainRegression <- Sys.time()
   time_date <- paste(Time_textTrainRegression,
-                     "; Date created: ", Date_textTrainRegression,
-                     sep = "",
-                     collapse = " "
+    "; Date created: ", Date_textTrainRegression,
+    sep = "",
+    collapse = " "
   )
 
 
@@ -1143,6 +1207,7 @@ textTrainRegression <- function(x,
     x_append_names_description,
     y_name_description,
     cv_method_description,
+    strata_description,
     outside_folds_description,
     outside_strata_y_description,
     inside_folds_description,
@@ -1289,6 +1354,13 @@ textTrainRegression <- function(x,
   remove(xy_all)
   remove(final_recipe)
 
+  # Remove objects to further minimize model size when saved to rds
+  remove(embedding_description)
+  remove(x_append_names_description)
+  remove(x_append_names)
+  remove(variable_name_index_pca)
+  remove(preprocessing_recipe_prep)
+  remove(nr_predictors)
+
   final_results
 }
-
