@@ -1,4 +1,3 @@
-
 #### Supervised Dimension Projection #####
 
 #' Creates the plot object (except for the legend).
@@ -49,7 +48,7 @@ textPlotting <- function(word_data_all = word_data_all,
     # ggrepel geom, make arrows transparent, color by rank, size by n
     ggrepel::geom_text_repel(
       data = word_data_all_yadjusted,
-      segment.alpha  = arrow_transparency,
+      segment.alpha = arrow_transparency,
       position = ggplot2::position_jitter(h = position_jitter_hight, w = position_jitter_width),
       ggplot2::aes(color = colour_categories, size = n, family = word_font),
     ) +
@@ -105,7 +104,7 @@ textPlotting <- function(word_data_all = word_data_all,
         title.position = "top",
         direction = "horizontal",
         label.position = "bottom",
-        ggplot2::element_text(color = titles_color)
+        title.theme = ggplot2::element_text(color = titles_color)
       )
     ) +
 
@@ -146,7 +145,6 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
                        legend_y_axes_label = legend_y_axes_label,
                        word_data_all = word_data_all,
                        legend_number_size = legend_number_size,
-                       # only_x_dimension = only_x_dimension,
                        titles_color = titles_color) {
   bivariate_color_data <- tibble::tibble(
     "1 - 3" = "#XXXXXX", "2 - 3" = "#XXXXXX", "3 - 3" = "#XXXXXX",
@@ -187,7 +185,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 1, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[1],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -197,7 +195,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 2, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[2],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -207,7 +205,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 3, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[3],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -215,19 +213,19 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
     } +
     ggplot2::annotate(
       geom = "text", x = 1, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[4],
-        na.rm = T
+        na.rm = TRUE
       ),
       color = titles_color, size = legend_number_size
     ) +
     ggplot2::annotate(
       geom = "text", x = 2, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[5],
-        na.rm = T
+        na.rm = TRUE
       ),
       color = titles_color, size = legend_number_size
     ) +
     ggplot2::annotate(
       geom = "text", x = 3, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[6],
-        na.rm = T
+        na.rm = TRUE
       ),
       color = titles_color, size = legend_number_size
     ) +
@@ -235,7 +233,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 1, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[7],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -245,7 +243,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 2, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[8],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -255,7 +253,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 3, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[9],
-            na.rm = T
+            na.rm = TRUE
           ),
           color = titles_color, size = legend_number_size
         )
@@ -290,16 +288,13 @@ textOwnWordsProjection <- function(word_data = word_data,
                                    space = space,
                                    text_plot_comment = text_plot_comment,
                                    scaling = scaling) {
-
   # For loop for different batches of added words; i_add_w=1 explore_words = "happy harmony love"
   forloops_add_w <- length(explore_words)
   added_words_information <- list()
 
   for (i_add_w in 1:forloops_add_w) {
-
     # If using a contextualized language model
     if (is.null(space) == TRUE) {
-
       # Creating word embeddings for the words.
       model_text <- sub(".*model: ", "", text_plot_comment)
       model_name <- sub(" ;.*", "", model_text)
@@ -367,24 +362,26 @@ textOwnWordsProjection <- function(word_data = word_data,
       manual_words_mean1 <- bind_rows(singlewords_we_x_scaled_w_n, Mean1)
     } else {
       # Aggregate the words
-      Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
-        explore_words_embeddings$word_types,
-        dplyr::starts_with("Dim")
-      ),
-      aggregation = explore_words_aggregation
+      Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(
+        dplyr::select(
+          explore_words_embeddings$word_types[[1]],
+          dplyr::starts_with("Dim")
+        ),
+        aggregation = explore_words_aggregation
       ))
       Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
-      manual_words_mean1 <- bind_rows(explore_words_embeddings$word_types, Mean1)
+      manual_words_mean1 <- bind_rows(explore_words_embeddings$word_types[[1]], Mean1)
     }
 
     #### Project embedding on the x axes ######
     projected_embedding.x <- as.vector(word_data$background[[1]]$Aggregated_word_embedding_group2.x -
-      word_data$background[[1]]$Aggregated_word_embedding_group1.x)
+                                         word_data$background[[1]]$Aggregated_word_embedding_group1.x)
 
     # Position words in relation to Aggregated word embedding
     # Position the embedding; i.e., taking the word embedding subtracted with aggregated word embedding
-    embedding_to_anchour_with.x <- tibble::as_tibble((word_data$background[[1]]$Aggregated_word_embedding_group2.x +
-      word_data$background[[1]]$Aggregated_word_embedding_group1.x) / 2)
+    embedding_to_anchour_with.x <- tibble::as_tibble(
+      (word_data$background[[1]]$Aggregated_word_embedding_group2.x +
+         word_data$background[[1]]$Aggregated_word_embedding_group1.x) / 2)
     manual_words_mean1_1.x <- dplyr::select(manual_words_mean1, dplyr::starts_with("Dim"))
 
     embedding_to_anchour_with.x_df <- embedding_to_anchour_with.x %>%
@@ -410,11 +407,12 @@ textOwnWordsProjection <- function(word_data = word_data,
 
     if (y_axes == TRUE) {
       projected_embedding.y <- as.vector(word_data$background[[2]]$Aggregated_word_embedding_group2.y -
-        word_data$background[[2]]$Aggregated_word_embedding_group1.y)
+                                           word_data$background[[2]]$Aggregated_word_embedding_group1.y)
       # Position words in relation to Aggregated word embedding
       # Position the embedding; i.e., taking the word embedding subtracted with aggregated word embedding
-      embedding_to_anchour_with.y <- tibble::as_tibble((word_data$background[[2]]$Aggregated_word_embedding_group2.y +
-        word_data$background[[2]]$Aggregated_word_embedding_group1.y) / 2)
+      embedding_to_anchour_with.y <- tibble::as_tibble(
+        (word_data$background[[2]]$Aggregated_word_embedding_group2.y +
+           word_data$background[[2]]$Aggregated_word_embedding_group1.y) / 2)
       manual_words_mean1_1.y <- dplyr::select(manual_words_mean1, dplyr::starts_with("Dim"))
 
       embedding_to_anchour_with.y_df <- embedding_to_anchour_with.y %>%
@@ -483,17 +481,14 @@ textOwnWordPrediction <- function(word_data = word_data,
                                   space = space,
                                   text_plot_comment = text_plot_comment,
                                   scaling = scaling) {
-
   # For loop for different batches of added words; i_add_w=1 explore_words = "happy harmony love"
   forloops_add_w <- length(explore_words)
   added_words_information <- list()
 
 
   for (i_add_w in 1:forloops_add_w) {
-
     # If using a contextualized language model
     if (is.null(space) == TRUE) {
-
       # Creating word embeddings for the words.
       model_text <- sub(".*model: ", "", text_plot_comment)
       model_name <- sub(" ; layer.*", "", model_text)
@@ -538,11 +533,12 @@ textOwnWordPrediction <- function(word_data = word_data,
     colnames(n_words) <- "n"
 
     # Aggregate the words
-    Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
-      explore_words_embeddings$word_types,
-      dplyr::starts_with("Dim")
-    ),
-    aggregation = explore_words_aggregation
+    Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(
+      dplyr::select(
+        explore_words_embeddings$word_types,
+        dplyr::starts_with("Dim")
+      ),
+      aggregation = explore_words_aggregation
     ))
     Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
     manual_words_mean1 <- bind_rows(explore_words_embeddings$word_types, Mean1)
@@ -618,46 +614,48 @@ adjust_for_plot_type <- function(word_data, y_axes) {
 
 
 #' Plot words from textProjection() or textWordPrediction().
-#' @param word_data Dataframe from textProjection
+#' @param word_data Dataframe from textProjection.
 #' @param k_n_words_to_test Select the k most frequent words to significance
-#' test (k = sqrt(100*N); N = number of participant responses). Default = TRUE.
+#' test (k = sqrt(100*N); N = number of participant responses) (default = TRUE).
 #' @param min_freq_words_test Select words to significance test that have occurred
 #' at least min_freq_words_test (default = 1).
 #' @param min_freq_words_plot Select words to plot that has occurred at
-#' least min_freq_words_plot times.
+#' least min_freq_words_plot times (default = 1).
 #' @param plot_n_words_square Select number of significant words in each square
 #' of the figure to plot. The significant words, in each square is selected
-#' according to most frequent words.
-#' @param plot_n_words_p Number of significant words to plot on each(positive
+#' according to most frequent words (default = 3).
+#' @param plot_n_words_p Number of significant words to plot on each (positive
 #' and negative) side of the x-axes and y-axes, (where duplicates are removed);
-#' selects first according to lowest p-value and then according to frequency. Hence, on a two
+#' selects first according to lowest p-value and then according to frequency (default = 5). Hence, on a two
 #' dimensional plot it is possible that plot_n_words_p = 1 yield 4 words.
 #' @param plot_n_word_extreme Number of words that are extreme on Supervised Dimension
-#' Projection per dimension. (i.e., even if not significant; per dimensions,
+#' Projection per dimension (default = 5). (i.e., even if not significant; per dimensions,
 #' where duplicates are removed).
-#' @param plot_n_word_frequency Number of words based on being most frequent.
+#' @param plot_n_word_frequency Number of words based on being most frequent (default = 5).
 #' (i.e., even if not significant).
 #' @param plot_n_words_middle Number of words plotted that are in the middle in Supervised
-#' Dimension Projection score (i.e., even if not significant;  per dimensions, where duplicates are removed).
-#' @param title_top Title (default "  ")
-#' @param titles_color Color for all the titles (default: "#61605e")
+#' Dimension Projection score (default = 5). (i.e., even if not significant;  per dimensions,
+#' where duplicates are removed).
+#' @param title_top Title (default "  ").
+#' @param titles_color Color for all the titles (default: "#61605e").
 # @param x_axes If TRUE, plotting on the x_axes.
-#' @param y_axes If TRUE, also plotting on the y-axes (default is FALSE). Also plotting on
-#' y-axes produces a two dimension 2-dimensional plot, but the textProjection function has to
-#' have had a variable on the y-axes.
+#' @param y_axes (boolean) If TRUE, also plotting on the y-axes (default = FALSE, i.e, a 1-dimensional
+#' plot is generated). Also plotting on y-axes produces a two dimension 2-dimensional plot, but the
+#' textProjection function has to have had a variable on the y-axes.
 #' @param p_alpha Alpha (default = .05).
-#' @param p_adjust_method Method to adjust/correct p-values for multiple comparisons
-#' (default = "holm"; see also "none", "hochberg", "hommel", "bonferroni", "BH", "BY",  "fdr").
-#' @param x_axes_label Label on the x-axes.
-#' @param y_axes_label Label on the y-axes.
+#' @param overlapping (boolean) Allow overlapping (TRUE) or disallow (FALSE) (default = TRUE).
+#' @param p_adjust_method (character) Method to adjust/correct p-values for multiple comparisons
+#' (default = "none"; see also "holm", "hochberg", "hommel", "bonferroni", "BH", "BY",  "fdr").
+#' @param x_axes_label (character) Label on the x-axes (default = "Supervised Dimension Projection (SDP)").
+#' @param y_axes_label (character) Label on the y-axes (default = "Supervised Dimension Projection (SDP)").
 #' @param scale_x_axes_lim Manually set the length of the x-axes (default = NULL, which uses
 #' ggplot2::scale_x_continuous(limits = scale_x_axes_lim); change e.g., by trying c(-5, 5)).
 #' @param scale_y_axes_lim Manually set the length of the y-axes (default = NULL; which uses
 #' ggplot2::scale_y_continuous(limits = scale_y_axes_lim); change e.g., by trying c(-5, 5)).
-#' @param word_font Font type (default: NULL).
-#' @param bivariate_color_codes The different colors of the words. Note that, at the moment, two
-#' squares should not have the exact same colour-code because the numbers within the squares of the
-#' legend will then be aggregated (and show the same, incorrect  value).
+#' @param word_font Font type (default = NULL).
+#' @param bivariate_color_codes (HTML color codes. Type = character) The different colors of the words.
+#'  Note that, at the moment, two squares should not have the exact same colour-code because the numbers
+#'  within the squares of the legend will then be aggregated (and show the same, incorrect  value).
 #' (default: c("#398CF9", "#60A1F7", "#5dc688",
 #' "#e07f6a", "#EAEAEA", "#40DD52",
 #' "#FF0000", "#EA7467", "#85DB8E")).
@@ -670,45 +668,45 @@ adjust_for_plot_type <- function(word_data, y_axes) {
 #' (default is to not show it, i.e., 0).
 #' @param points_without_words_alpha Transparency of the points not linked with a words
 #' (default is to not show it, i.e., 0).
-#' @param legend_title Title on the color legend (default: "(SDP)".
-#' @param legend_x_axes_label Label on the color legend (default: "(x)".
-#' @param legend_y_axes_label Label on the color legend (default: "(y)".
+#' @param legend_title Title on the color legend (default: "SDP").
+#' @param legend_x_axes_label Label on the color legend (default: "x").
+#' @param legend_y_axes_label Label on the color legend (default: "y").
 #' @param legend_x_position Position on the x coordinates of the color legend (default: 0.02).
 #' @param legend_y_position Position on the y coordinates of the color legend (default: 0.05).
 #' @param legend_h_size Height of the color legend (default 0.15).
 #' @param legend_w_size Width of the color legend (default 0.15).
 #' @param legend_title_size Font size (default: 7).
 #' @param legend_number_size Font size of the values in the legend (default: 2).
-#' @param group_embeddings1 Shows a point representing the aggregated word embedding
+#' @param group_embeddings1 (boolean) Shows a point representing the aggregated word embedding
 #' for group 1 (default = FALSE).
-#' @param group_embeddings2 Shows a point representing the aggregated word embedding
+#' @param group_embeddings2 (boolean) Shows a point representing the aggregated word embedding
 #' for group 2 (default = FALSE).
-#' @param projection_embedding Shows a point representing the aggregated direction
+#' @param projection_embedding (boolean) Shows a point representing the aggregated direction
 #' embedding (default = FALSE).
 #' @param aggregated_point_size Size of the points representing the group_embeddings1,
-#' group_embeddings2 and projection_embedding.
+#' group_embeddings2 and projection_embedding (default = 0.8).
 #' @param aggregated_shape Shape type of the points representing the group_embeddings1,
-#' group_embeddings2 and projection_embedding.
-#' @param aggregated_color_G1 Color
-#' @param aggregated_color_G2 Color
-#' @param projection_color Color
-#' @param seed Set different seed.
+#' group_embeddings2 and projection_embedding (default = 8).
+#' @param aggregated_color_G1 Color (default = "black").
+#' @param aggregated_color_G2 Color (default = "black").
+#' @param projection_color Color (default = "blue").
+#' @param seed (numeric) Set different seed (default = 1005)..
 #' @param explore_words Explore where specific words are positioned in the embedding space.
-#' For example, c("happy content", "sad down").
+#' For example, c("happy content", "sad down") (default = NULL).
 #' @param explore_words_color Specify the color(s) of the words being explored.
-#' For example c("#ad42f5", "green")
+#' For example c("#ad42f5", "green") (default = "#ad42f5").
 #' @param explore_words_point Specify the names of the point for the aggregated word embeddings
-#' of all the explored words.
+#' of all the explored words (default = "ALL_1").
 #' @param explore_words_aggregation Specify how to aggregate the word embeddings of
-#' the explored words.
-#' @param remove_words manually remove words from the plot (which is done just before the
-#' words are plotted so that the remove_words are part of previous counts/analyses).
-#' @param space Provide a semantic space if using static embeddings and wanting to explore words.
+#' the explored words (default = "mean").
+#' @param remove_words Manually remove words from the plot (which is done just before the
+#' words are plotted so that the remove_words are part of previous counts/analyses) (default = NULL).
+#' @param space Provide a semantic space if using static embeddings and wanting to explore words (default = NULL).
 #' @param n_contrast_group_color Set color to words that have higher frequency (N)
 #' on the other opposite side of its dot product projection (default = NULL).
 #' @param n_contrast_group_remove Remove words that have higher frequency (N) on the other
 #' opposite side of its dot product projection (default = FALSE).
-#' @param scaling Scaling word embeddings before aggregation.
+#' @param scaling Scaling word embeddings before aggregation (default = FALSE).
 #' @return A 1- or 2-dimensional word plot, as well as tibble with processed data used
 #' to plot.
 #' @examples
@@ -735,7 +733,7 @@ adjust_for_plot_type <- function(word_data, y_axes) {
 #' plot_projection
 #'
 #' names(DP_projections_HILS_SWLS_100)
-#' @seealso see \code{\link{textProjection}}
+#' @seealso See \code{\link{textProjection}}.
 #' @importFrom tibble as_tibble tibble
 #' @importFrom dplyr row_number slice mutate mutate_if bind_rows group_by summarize left_join %>% n
 #' @importFrom tidyr gather separate
@@ -756,9 +754,9 @@ textPlot <- function(word_data,
                      plot_n_word_frequency = 5,
                      plot_n_words_middle = 5,
                      titles_color = "#61605e",
-                     # x_axes = TRUE,
                      y_axes = FALSE,
                      p_alpha = 0.05,
+                     overlapping = TRUE,
                      p_adjust_method = "none",
                      title_top = "Supervised Dimension Projection",
                      x_axes_label = "Supervised Dimension Projection (SDP)",
@@ -805,8 +803,6 @@ textPlot <- function(word_data,
                      n_contrast_group_remove = FALSE,
                      space = NULL,
                      scaling = FALSE) {
-
-
   ##### Comment to be saved ####
   text_plot_comment <- paste(
     "INFORMATION ABOUT THE PROJECTION",
@@ -823,6 +819,7 @@ textPlot <- function(word_data,
     "plot_n_words_middle =", plot_n_words_middle,
     "y_axes =", y_axes,
     "p_alpha =", p_alpha,
+    "overlapping", overlapping,
     "p_adjust_method =", p_adjust_method,
     "bivariate_color_codes =", paste(bivariate_color_codes, collapse = " "),
     "word_size_range =", paste(word_size_range, sep = "-", collapse = " - "),
@@ -863,6 +860,11 @@ textPlot <- function(word_data,
     y_axes_values_hide <- TRUE
   }
 
+  #### Allow overlapping ####
+  if (overlapping == TRUE) {
+    options(ggrepel.max.overlaps = 1000)
+  }
+
   #### Removing words MANUALY #######
 
   if (!is.null(remove_words)) {
@@ -899,7 +901,8 @@ textPlot <- function(word_data,
       purrr::as_vector(word_data1_padjusted_y[, "p_values_y"]),
       method = p_adjust_method
     )
-    word_data1 <- dplyr::left_join(word_data1, word_data1_padjusted_y[, c("words", "adjusted_p_values.y")], by = "words")
+    word_data1 <- dplyr::left_join(word_data1,
+                                   word_data1_padjusted_y[, c("words", "adjusted_p_values.y")], by = "words")
   }
 
   # Select only min_freq_words_plot to plot (i.e., after correction of multiple comparison for sig. test)
@@ -1009,23 +1012,23 @@ textPlot <- function(word_data,
 
   word_data1_x <- word_data1 %>%
     dplyr::left_join(data_p_sq_all %>%
-      dplyr::transmute(words, check_p_square = 1), by = "words") %>%
+                       dplyr::transmute(words, check_p_square = 1), by = "words") %>%
     dplyr::left_join(data_p_x_neg %>%
-      dplyr::transmute(words, check_p_x_neg = 1), by = "words") %>%
+                       dplyr::transmute(words, check_p_x_neg = 1), by = "words") %>%
     dplyr::left_join(data_p_x_pos %>%
-      dplyr::transmute(words, check_p_x_pos = 1), by = "words") %>%
+                       dplyr::transmute(words, check_p_x_pos = 1), by = "words") %>%
     dplyr::left_join(word_data1_extrem_max_x %>%
-      dplyr::transmute(words, check_extreme_max_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_max_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_extrem_min_x %>%
-      dplyr::transmute(words, check_extreme_min_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_min_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_frequency_x %>%
-      dplyr::transmute(words, check_extreme_frequency_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_frequency_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_middle_x %>%
-      dplyr::transmute(words, check_middle_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_middle_x = 1), by = "words") %>%
     dplyr::mutate(extremes_all_x = rowSums(cbind(
       check_p_square, check_p_x_neg, check_p_x_pos, check_extreme_max_x, check_extreme_min_x,
       check_extreme_frequency_x, check_middle_x
-    ), na.rm = T))
+    ), na.rm = TRUE))
 
 
   ###### Sort words for y-axes.
@@ -1065,22 +1068,22 @@ textPlot <- function(word_data,
 
     word_data_all <- word_data1_x %>%
       dplyr::left_join(data_p_y_pos %>%
-        dplyr::transmute(words, check_p_y_pos = 1), by = "words") %>%
+                         dplyr::transmute(words, check_p_y_pos = 1), by = "words") %>%
       dplyr::left_join(data_p_y_neg %>%
-        dplyr::transmute(words, check_p_y_neg = 1), by = "words") %>%
+                         dplyr::transmute(words, check_p_y_neg = 1), by = "words") %>%
       dplyr::left_join(word_data1_extrem_max_y %>%
-        dplyr::transmute(words, check_extreme_max_y = 1), by = "words") %>%
+                         dplyr::transmute(words, check_extreme_max_y = 1), by = "words") %>%
       dplyr::left_join(word_data1_extrem_min_y %>%
-        dplyr::transmute(words, check_extreme_min_y = 1), by = "words") %>%
+                         dplyr::transmute(words, check_extreme_min_y = 1), by = "words") %>%
       dplyr::left_join(word_data1_frequency_y %>%
-        dplyr::transmute(words, check_extreme_frequency_y = 1), by = "words") %>%
+                         dplyr::transmute(words, check_extreme_frequency_y = 1), by = "words") %>%
       dplyr::left_join(word_data1_middle_y %>%
-        dplyr::transmute(words, check_middle_y = 1), by = "words") %>%
+                         dplyr::transmute(words, check_middle_y = 1), by = "words") %>%
       dplyr::mutate(extremes_all_y = rowSums(cbind(
         check_p_y_neg, check_p_y_pos, check_extreme_max_y, check_extreme_min_y,
         check_extreme_frequency_y, check_middle_y
-      ), na.rm = T)) %>%
-      dplyr::mutate(extremes_all = rowSums(cbind(extremes_all_x, extremes_all_y), na.rm = T))
+      ), na.rm = TRUE)) %>%
+      dplyr::mutate(extremes_all = rowSums(cbind(extremes_all_x, extremes_all_y), na.rm = TRUE))
 
 
     # Categorize words to apply specific color
@@ -1113,16 +1116,15 @@ textPlot <- function(word_data,
 
   #### Colorize words that are more frequent on the opposite side of the dot product projection ####
   if (is.character(n_contrast_group_color) == TRUE) {
-
     # Select words with MORE words in G1 and POSITIVE dot product (i.e., remove words that are
     # more represented in the opposite group of its dot product projection)
     word_data_all$colour_categories[(abs(word_data_all$n_g1.x) > abs(word_data_all$n_g2.x) &
-      word_data_all$x_plotted > 0)] <- n_contrast_group_color
+                                       word_data_all$x_plotted > 0)] <- n_contrast_group_color
 
     # Select words with MORE words in G2 and POSITIVE dot product (i.e., remove words that are more
     # represented in the opposite group of its dot product projection)
     word_data_all$colour_categories[(abs(word_data_all$n_g1.x) < abs(word_data_all$n_g2.x) &
-      word_data_all$x_plotted < 0)] <- n_contrast_group_color
+                                       word_data_all$x_plotted < 0)] <- n_contrast_group_color
   }
 
   #### Remove more frequent words on the opposite side of the dot product projection ####
@@ -1131,13 +1133,13 @@ textPlot <- function(word_data,
       # Select words with MORE words in G1 and NEGATIVE dot product (i.e., do not select words
       # that are more represented in the opposite group of its dot product projection)
       filter((abs(n_g1.x) > abs(n_g2.x) &
-        x_plotted < 0))
+                x_plotted < 0))
 
     word_data_all2 <- word_data_all %>%
       # Select words with MORE words in G2 and POSITIVE dot product (i.e., do not select words that
       # are more represented in the opposite group of its dot product projection)
       filter((abs(n_g1.x) < abs(n_g2.x) &
-        x_plotted > 0))
+                x_plotted > 0))
 
     word_data_all <- bind_rows(word_data_all1, word_data_all2)
   }
@@ -1237,6 +1239,10 @@ textPlot <- function(word_data,
     y_axes_label = y_axes_label,
     y_axes_values = y_axes_values
   )
+
+  #### Reset overlapping ####
+  options(ggrepel.max.overlaps = 10)
+
   # plot
 
   #### Creating the legend ####
@@ -1251,15 +1257,18 @@ textPlot <- function(word_data,
     legend_y_axes_label = legend_y_axes_label,
     word_data_all = word_data_all,
     legend_number_size = legend_number_size,
-    # only_x_dimension = only_x_dimension,
     titles_color = titles_color
   )
   # legend
 
   #### Plot both figure and legend help(null_dev_env) ####
   final_plot <- suppressWarnings(cowplot::ggdraw() +
-    cowplot::draw_plot(plot, 0, 0, 1, 1) +
-    cowplot::draw_plot(legend, legend_x_position, legend_y_position, legend_h_size, legend_w_size))
+                                   cowplot::draw_plot(plot, 0, 0, 1, 1) +
+                                   cowplot::draw_plot(legend,
+                                                      legend_x_position,
+                                                      legend_y_position,
+                                                      legend_h_size,
+                                                      legend_w_size))
 
   output_plot_data <- list(final_plot, text_plot_comment, word_data_all)
   names(output_plot_data) <- c("final_plot", "description", "processed_word_data")
