@@ -1,31 +1,37 @@
-
 #### Semantic Centrality Plot SC ####
 
 #' Compute semantic similarity score between single words' word embeddings
 #' and the aggregated word embedding of all words.
-#' @param words Word or text variable to be plotted.
+#' @param words (character) Word or text variable to be plotted.
 #' @param word_embeddings Word embeddings from textEmbed for the words to be plotted
 #' (i.e., the aggregated word embeddings for the "words" variable).
 #' @param word_types_embeddings Word embeddings from textEmbed for individual words
 #' (i.e., the decontextualized word embeddings).
 #' @inheritParams textSimilarity
-#' @param aggregation Method to aggregate the word embeddings
+#' @param aggregation (character) Method to aggregate the word embeddings
 #' (default = "mean"; see also "min", "max" or "[CLS]").
-#' @param min_freq_words_test Option to  select words that have at least occurred a specified
+#' @param min_freq_words_test (numeric) Option to select words that have at least occurred a specified
 #' number of times (default = 0); when creating the semantic similarity
 #' scores.
 #' @return A dataframe with variables (e.g., including semantic similarity, frequencies)
-#' for the individual words that are used for the plotting in the textCentralityPlot function.
+#' for the individual words that are used as input for the plotting in the textCentralityPlot function.
 #' @examples
+#' # Computes the semantic similarity between the individual word embeddings (Iwe)
+#' # in the "harmonywords" column of the pre-installed dataset: Language_based_assessment_data_8,
+#' # and the aggregated word embedding (Awe).
+#' # The Awe can be interpreted the latent meaning of the text.
+#'
 #' \dontrun{
 #' df_for_plotting <- textCentrality(
-#'   words = Language_based_assessment_data_8$harmonywords,
+#'   words = Language_based_assessment_data_8["harmonywords"],
 #'   word_embeddings = word_embeddings_4$texts$harmonywords,
 #'   word_types_embeddings = word_embeddings_4$word_types
 #' )
-#' df_for_plotting
+#'
+#' # df_for_plotting contain variables (e.g., semantic similarity, frequencies) for
+#' # the individual words that are used for plotting by the textCentralityPlot function.
 #' }
-#' @seealso see \code{\link{textCentralityPlot}}  \code{\link{textProjection}}
+#' @seealso See \code{\link{textCentralityPlot}} and \code{\link{textProjection}}.
 #' @importFrom dplyr bind_rows
 #' @importFrom tibble tibble
 #' @export
@@ -67,29 +73,29 @@ textCentrality <- function(words,
 # End Semantic Centrality Plot data
 
 #' Plot words according to semantic similarity to the aggregated word embedding.
-#' @param word_data Tibble from textPlotData.
+#' @param word_data Tibble from the textPlot function.
 #' @param min_freq_words_test Select words to significance test that have occurred
 #' at least min_freq_words_test (default = 1).
 #' @param plot_n_word_extreme Number of words per dimension to plot with extreme
-#' Supervised Dimension Projection value.
+#' Supervised Dimension Projection value (default = 10).
 #' (i.e., even if not significant;  duplicates are removed).
-#' @param plot_n_word_frequency Number of words to plot according to their frequency.
+#' @param plot_n_word_frequency Number of words to plot according to their frequency (default = 10).
 #' (i.e., even if not significant).
-#' @param plot_n_words_middle Number of words to plot that are in the middle in Supervised Dimension Projection score
-#' (i.e., even if not significant; duplicates are removed).
-#' @param title_top Title (default "  ").
+#' @param plot_n_words_middle Number of words to plot that are in the middle in Supervised Dimension
+#' Projection score (default = 10). (i.e., even if not significant; duplicates are removed).
+#' @param title_top Title (default: "  ").
 #' @param titles_color Color for all the titles (default: "#61605e").
-#' @param x_axes Variable to be plotted on the x-axes (default is "central_semantic_similarity",
+#' @param x_axes Variable to be plotted on the x-axes (default: "central_semantic_similarity",
 #' could also select "n", "n_percent").
-#' @param x_axes_label Label on the x-axes.
+#' @param x_axes_label Label on the x-axes (default: "Semantic Centrality").
 #' @param scale_x_axes_lim Length of the x-axes (default: NULL, which uses
 #' c(min(word_data$central_semantic_similarity)-0.05, max(word_data$central_semantic_similarity)+0.05);
 #' change this by e.g., try c(-5, 5)).
 #' @param scale_y_axes_lim Length of the y-axes (default: NULL, which uses c(-1, 1);
 #' change e.g., by trying c(-5, 5)).
 #' @param word_font Type of font (default: NULL).
-#' @param centrality_color_codes Colors of the words selected as plot_n_word_extreme
-#' (minimum values), plot_n_words_middle, plot_n_word_extreme (maximum values) and
+#' @param centrality_color_codes (HTML color codes. type = character) Colors of the words selected as
+#' plot_n_word_extreme (minimum values), plot_n_words_middle, plot_n_word_extreme (maximum values) and
 #' plot_n_word_frequency; the default is c("#EAEAEA", "#85DB8E", "#398CF9", "#9e9d9d", respectively.
 #' @param word_size_range Vector with minimum and maximum font size (default: c(3, 8)).
 #' @param position_jitter_hight Jitter height (default: .0).
@@ -100,43 +106,55 @@ textCentrality <- function(words,
 #' (default is to not show the point; , i.e., 0).
 #' @param points_without_words_alpha Transparency of the points that are not linked to a word
 #' (default is to not show it; i.e., 0).
-#' @param legend_title Title of the color legend (default: "(SCP)").
-#' @param legend_x_axes_label Label on the color legend (default: "(x)".
-#' @param legend_x_position Position on the x coordinates of the color legend (default: 0.02).
-#' @param legend_y_position Position on the y coordinates of the color legend (default: 0.05).
-#' @param legend_h_size Height of the color legend (default 0.15).
-#' @param legend_w_size Width of the color legend (default 0.15).
+#' @param legend_title Title of the color legend (default: "SCP").
+#' @param legend_x_axes_label Label on the color legend (default: "x").
+#' @param legend_x_position Position on the x coordinates of the color legend (default = 0.02).
+#' @param legend_y_position Position on the y coordinates of the color legend (default = 0.05).
+#' @param legend_h_size Height of the color legend (default = 0.15).
+#' @param legend_w_size Width of the color legend (default = 0.15).
 #' @param legend_title_size Font size of the title (default = 7).
 #' @param legend_number_size Font size of the values in the legend (default = 2).
-#' @param seed Set different seed.
+#' @param seed Set different seed (default = 1007).
 #' @return A 1-dimensional word plot based on similarity to the aggregated word embedding,
 #' as well as tibble with processed data used to plot.
-#' @seealso see \code{\link{textCentrality}} and \code{\link{textProjection}}
+#' @seealso See \code{\link{textCentrality}} and \code{\link{textProjection}}.
 #' @examples
-#' # The test-data included in the package is called: centrality_data_harmony
-#' names(centrality_data_harmony)
-#' # Plot
-#' # centrality_plot <- textCentralityPlot(
-#' #  word_data = centrality_data_harmony,
-#' #  min_freq_words_test = 10,
-#' #  plot_n_word_extreme = 10,
-#' #  plot_n_word_frequency = 10,
-#' #  plot_n_words_middle = 10,
-#' #  titles_color = "#61605e",
-#' #  x_axes = "central_semantic_similarity",
-#' #
-#' #  title_top = "Semantic Centrality Plot",
-#' #  x_axes_label = "Semantic Centrality",
-#' #
-#' #  word_font = NULL,
-#' #  centrality_color_codes = c("#EAEAEA", "#85DB8E", "#398CF9", "#9e9d9d"),
-#' #  word_size_range = c(3, 8),
-#' #  point_size = 0.5,
-#' #  arrow_transparency = 0.1,
-#' #  points_without_words_size = 0.5,
-#' #  points_without_words_alpha = 0.5,
-#' # )
-#' # centrality_plot
+#' # Plot a centrality plot from the dataframe df_for_plotting
+#' # that is returned by the textCentrality function.
+#' \dontrun{
+#' textCentralityPlot(
+#'   df_for_plotting,
+#'   min_freq_words_test = 1,
+#'   plot_n_word_extreme = 10,
+#'   plot_n_word_frequency = 10,
+#'   plot_n_words_middle = 10,
+#'   titles_color = "#61605e",
+#'   x_axes = "central_semantic_similarity",
+#'   title_top = "Semantic Centrality Plot",
+#'   x_axes_label = "Semantic Centrality",
+#'   scale_x_axes_lim = NULL,
+#'   scale_y_axes_lim = NULL,
+#'   word_font = NULL,
+#'   centrality_color_codes = c("#EAEAEA", "#85DB8E", "#398CF9", "#9e9d9d"),
+#'   word_size_range = c(3, 8),
+#'   position_jitter_hight = 0,
+#'   position_jitter_width = 0.03,
+#'   point_size = 0.5,
+#'   arrow_transparency = 0.1,
+#'   points_without_words_size = 0.5,
+#'   points_without_words_alpha = 0.5,
+#'   legend_title = "SC",
+#'   legend_x_axes_label = "x",
+#'   legend_x_position = 0.02,
+#'   legend_y_position = 0.02,
+#'   legend_h_size = 0.2,
+#'   legend_w_size = 0.2,
+#'   legend_title_size = 7,
+#'   legend_number_size = 2,
+#'   seed = 1007
+#' )
+#' }
+#'
 #' @importFrom dplyr arrange slice filter between left_join transmute mutate case_when
 #' @importFrom ggplot2 position_jitter element_text element_blank coord_fixed theme
 #' theme_void theme_minimal aes labs scale_color_identity
@@ -230,17 +248,17 @@ textCentralityPlot <- function(word_data,
 
   word_data1_all <- word_data1 %>%
     dplyr::left_join(word_data1_extrem_max_x %>%
-      dplyr::transmute(words, check_extreme_max_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_max_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_extrem_min_x %>%
-      dplyr::transmute(words, check_extreme_min_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_min_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_frequency_x %>%
-      dplyr::transmute(words, check_extreme_frequency_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_extreme_frequency_x = 1), by = "words") %>%
     dplyr::left_join(word_data1_middle_x %>%
-      dplyr::transmute(words, check_middle_x = 1), by = "words") %>%
+                       dplyr::transmute(words, check_middle_x = 1), by = "words") %>%
     dplyr::mutate(extremes_all_x = rowSums(cbind(
       check_extreme_max_x, check_extreme_min_x,
       check_extreme_frequency_x, check_middle_x
-    ), na.rm = T))
+    ), na.rm = TRUE))
 
   # Categorise words to apply specific color View(word_data1_all)
   word_data1_all <- word_data1_all %>%
@@ -252,15 +270,15 @@ textCentralityPlot <- function(word_data,
     ))
 
   if (is.null(scale_x_axes_lim)) {
-    scale_x_axes_lim <- c(min(word_data1[[eval(x_axes)]], na.rm = T) -
-      0.05, max(word_data1[[eval(x_axes)]], na.rm = T) + 0.05)
+    scale_x_axes_lim <- c(min(word_data1[[eval(x_axes)]], na.rm = TRUE) -
+                            0.05, max(word_data1[[eval(x_axes)]], na.rm = TRUE) + 0.05)
   }
   if (is.null(scale_y_axes_lim)) {
     scale_y_axes_lim <- c(-1, 1)
   }
 
   # This solution is because it is not possible to send "0" as a parameter
-  only_x_dimension <- 0
+  # only_x_dimension <- 0
   y_axes <- "only_x_dimension"
 
   # Plot
@@ -280,7 +298,7 @@ textCentralityPlot <- function(word_data,
     # ggrepel geom, make arrows transparent, color by rank, size by n
     ggrepel::geom_text_repel(
       data = word_data1_all[word_data1_all$extremes_all_x >= 1, ],
-      segment.alpha  = arrow_transparency,
+      segment.alpha = arrow_transparency,
       position = ggplot2::position_jitter(h = position_jitter_hight, w = position_jitter_width),
       ggplot2::aes(color = colour_categories, size = n, family = word_font),
     ) +
@@ -301,7 +319,7 @@ textCentralityPlot <- function(word_data,
         title.position = "top",
         direction = "horizontal",
         label.position = "bottom",
-        ggplot2::element_text(color = titles_color)
+        title.theme = ggplot2::element_text(color = titles_color)
       )
     ) +
 
