@@ -6,9 +6,9 @@ test_that("installing text", {
 
   textrpp_install(prompt = FALSE)
 
-  textrpp_initialize(textEmbed_test=FALSE)
+  textrpp_initialize(textEmbed_test = FALSE)
 
   text_test <- textEmbed("hello")
 
-  expect_that(ncol(text_test[[1]]), equals(1536))
+  expect_equal(text_test$tokens$texts[[1]]$Dim1[[1]], -0.9554495, tolerance = 0.0001)
 })
